

#include <X11/Xresource.h>

#define USE     ".use"
#define BUTTONS ".buttons"
#define XPOSI   ".xposi"
#define YPOSI   ".yposi"
#define STEPS   ".steps"
#define ALIGN   ".align"
#define AT      ".at"
#define COLOR   ".color"
#define FONT1   ".font1"
#define FONT2   ".font2"
#define RES     ".resource"

static int option_entries = 20;

static XrmOptionDescRec options[] =
{
  {"-h",    USE,     XrmoptionNoArg,  (caddr_t) "h"},
  {"-help", USE,     XrmoptionNoArg,  (caddr_t) "h"},
  {"-u",    USE,     XrmoptionNoArg,  (caddr_t) "h"},
  
  {"-b",    BUTTONS, XrmoptionSepArg, (caddr_t) NULL},
  
  {"-l",    ALIGN,   XrmoptionNoArg,  (caddr_t) "l"},
  {"-c",    ALIGN,   XrmoptionNoArg,  (caddr_t) "c"},
  {"-r",    ALIGN,   XrmoptionNoArg,  (caddr_t) "r"},
  {"-x",    XPOSI,   XrmoptionSepArg, (caddr_t) NULL},
  {"-y",    YPOSI,   XrmoptionSepArg, (caddr_t) NULL},
  {"-s",    STEPS,   XrmoptionSepArg, (caddr_t) NULL},
  
  {"-B",    AT,      XrmoptionNoArg,  (caddr_t) "B"},
  {"-T",    AT,      XrmoptionNoArg,  (caddr_t) "T"},
  {"-L",    AT,      XrmoptionNoArg,  (caddr_t) "L"},
  {"-R",    AT,      XrmoptionNoArg,  (caddr_t) "R"},
  
  {"-BW",   COLOR,   XrmoptionNoArg,  (caddr_t) "B"},
  {"-C",    COLOR,   XrmoptionNoArg,  (caddr_t) "C"},
  {"-fn1",  FONT1,   XrmoptionSepArg, (caddr_t) NULL},
  {"-fn2",  FONT2,   XrmoptionSepArg, (caddr_t) NULL},
  
  {"-f",    RES,     XrmoptionSepArg, (caddr_t) NULL},
  
  {"-display", ".display", XrmoptionSepArg,  (caddr_t) NULL},
};

static XrmDatabase optionsdb;

char *str_type[32];
XrmValue value;

char *display_name, *buttons, *xposi, *yposi, *ssteps, 
     *align, *at, *color, *font1, *font2, *res_file;

void usage()
{
  cout << "\n\
  XFFM - X-Window Floating File Menu V1.0 (c)July 1997 by Michael Sohmen \n\

  This program is freeware, according to the GNU GENERAL PUBLIC LICENSE (for details see below).
  
  > This program is free software; you can redistribute it and/or modify
  > it under the terms of the GNU General Public License as published by
  > the Free Software Foundation; either version 2 of the License, or
  > (at your option) any later version.
  
  > This program is distributed in the hope that it will be useful,
  > but WITHOUT ANY WARRANTY; without even the implied warranty of
  > MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  > GNU General Public License for more details.
  
  > You should have received a copy of the GNU General Public License
  > along with this program; if not, write to the Free Software
  > Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  usage: xffm [Options] \n\
  Options: \n\
     -h / -help / -u      this menu \n\
     -b <number>          Create menu from button number(s) (default=3) \n\
                          Example :   -b 3  or  -b 123 \n\
     -l                   Left aligned menu (default) \n\
     -c                   Centered menu \n\
     -r                   Right aligned menu \n\
     -x <number>          Menu start position for aligned menu (default=2) \n\
     -y <number>          Menu distance from border (default=0) \n\
     -s <number 1..15>    Menu raise/drop steps, fluidity (default=5)\n\
     \n\
     -B                   Menu at bottom of display (default) \n\
     -T                   Menu at top of display \n\
     -L                   Menu at left border of display (not supported yet..)\n\
     -R                   Menu at right border of display (not supported yet..)\n\
     \n\
     -BW                  Use black&white colors (default) \n\
     -C                   Use 16 colors (not supported yet..)\n\
     -fn1 <fontname>      Font to use for superscription\n\
     -fn2 <fontname>      Font to use for buttons\n\
     
     -f <resource file>   Window manager's resource file or any other file \n\
                          that contains a menu on root window (with path). \n\
                          If no file is given, it uses the HOME/.xffmrc file \n\
                          or system.xffmrc. \n";
  exit(0);
}


CommandLineOptions(int argc, char *argv[])
{
  XrmParseCommand(&optionsdb, options, option_entries, argv[0], &argc, argv);
  if (argc != 1)
  {
    cout << "  -- unknown option: " << argv[1] << " --\n";
    usage();
  }
  
  if (XrmGetResource(optionsdb, "xffm.use",      "Xffm.Use",     str_type, &value)==True)
    usage();
    
  if (XrmGetResource(optionsdb, "xffm.display",  "Xffm.Display", str_type, &value)==True)
    display_name=strdup(value.addr);
  else
    display_name=strdup("");
     
  if (XrmGetResource(optionsdb, "xffm.buttons",  "Xffm.Buttons", str_type, &value)==True)
    buttons=strdup(value.addr);
  else
    buttons=strdup("3");
     
  if (XrmGetResource(optionsdb, "xffm.xposi",    "Xffm.Xposi",   str_type, &value)==True)
    xposi=strdup(value.addr);
  else
    xposi=strdup("2");

  if (XrmGetResource(optionsdb, "xffm.yposi",    "Xffm.Yposi",   str_type, &value)==True)
    yposi=strdup(value.addr);
  else
    yposi=strdup("0");
     
  if (XrmGetResource(optionsdb, "xffm.steps",    "Xffm.Steps",   str_type, &value)==True)
    ssteps=strdup(value.addr);
  else
    ssteps=strdup("5");
     
  if (XrmGetResource(optionsdb, "xffm.align",    "Xffm.Align",   str_type, &value)==True)
    align=strdup(value.addr);
  else
    align=strdup("l");
     
  if (XrmGetResource(optionsdb, "xffm.at",       "Xffm.At",      str_type, &value)==True)
    at=strdup(value.addr);
  else
    at=strdup("B");
     
  if (XrmGetResource(optionsdb, "xffm.color",    "Xffm.Color",   str_type, &value)==True)
    color=strdup(value.addr);
  else
    color=strdup("BW");
     
  if (XrmGetResource(optionsdb, "xffm.font1",    "Xffm.Fn1",   str_type, &value)==True)
    font1=strdup(value.addr);
  else
    font1=strdup("7x14bold");
     
  if (XrmGetResource(optionsdb, "xffm.font2",    "Xffm.Fn2",   str_type, &value)==True)
    font2=strdup(value.addr);
  else
    font2=strdup("7x14");
     
/*  if (XrmGetResource(optionsdb, "xffm.font1",    "Xffm.Fn1",   str_type, &value)==True)
    font1=strdup(value.addr);
  else
    font1=strdup("lucidasans-bolditalic-12");
     
  if (XrmGetResource(optionsdb, "xffm.font2",    "Xffm.Fn2",   str_type, &value)==True)
    font2=strdup(value.addr);
  else
    font2=strdup("lucidasans-italic-12");*/
     
  if (XrmGetResource(optionsdb, "xffm.resource", "Xffm.Resource",str_type, &value)==True)
    res_file=strdup(value.addr);
  else
    res_file=strdup("xffmrc");
}

